@@ -249,7 +249,7 @@ static inline int textporter_error_check(int iRet, char *path2, char *pdffile)
     char textporter_error[64];
     int null_strlen;
     int i = 0;
-    option = GetConfigOption("ludia.textporter_error");
+    option = getludiaoption("ludia.textporter_error");
     if (option) {
       strncpy(textporter_error, option, 64);
     } else {
@@ -340,7 +340,7 @@ pgs2textporter1(PG_FUNCTION_ARGS)
   {
     const char *option;
     char textporter_log[16];
-    option = GetConfigOption("ludia.textporter_log");
+    option = getludiaoption("ludia.textporter_log");
     if (option) {
       strncpy(textporter_log, option, 16);
     } else {
@@ -438,7 +438,7 @@ pgs2textporter2(PG_FUNCTION_ARGS)
   {
     const char *option;
     char textporter_log[16];
-    option = GetConfigOption("ludia.textporter_log");
+    option = getludiaoption("ludia.textporter_log");
     if (option) {
       strncpy(textporter_log, option, 16);
     } else {
