@@ -20,6 +20,8 @@ PG_FUNCTION_INFO_V1(pgs2version);
 PG_FUNCTION_INFO_V1(pgs2seninfo);
 PG_FUNCTION_INFO_V1(pgs2getoption);
 
+Datum _pgs2indexinfo(FunctionCallInfo fcinfo, char *path);
+
 #ifdef WIN32
 #if defined(POSTGRES81)
 extern DLLIMPORT char *DataDir;
@@ -148,7 +150,8 @@ do_dir_indexinfo(const char *dirname, int *n, sen_index_list *si_list)
       idxname[len] = '\0';
       sindex = sen_index_open(idxname);
       if (sindex == NULL) {
-        elog(ERROR, "pgsenna2: pgs2indexinfo cannot open senna index.");
+        elog(ERROR, "pgsenna2: pgs2indexinfo cannot open senna index %s",
+             idxname);
       }
       si_list_next = (sen_index_list *)palloc(sizeof(*si_list_next));
       sen_index_info(sindex,
@@ -332,7 +335,8 @@ do_dir_getlexicon(const char *dirname, int *n, sym_array **s_array, char *filena
         keybuf = (char *) palloc(sizeof(char *) * SEN_SYM_MAX_KEY_SIZE);
         sindex = sen_index_open(idxname);
         if (sindex == NULL) {
-          elog(ERROR, "pgsenna2: pgs2getlexicon cannot open senna index.");
+          elog(ERROR, "pgsenna2: pgs2getlexicon cannot open senna index %s",
+               idxname);
         }
         (*n) = 0;
         s_array = (sym_array **) palloc(sen_sym_size(sindex->lexicon) *
@@ -432,7 +436,7 @@ pgs2getlexicon(PG_FUNCTION_ARGS)
     snprintf(values[2], 16, "%d", s_array[call_cntr]->flag);
     tuple = BuildTupleFromCStrings(attinmeta, values);
     result = HeapTupleGetDatum(tuple);
-    for(i = 0; i < 2; i++) {
+    for(i = 0; i < 3; i++) {
       pfree(values[i]);
     }
     pfree(values);
@@ -516,7 +520,7 @@ pgs2getoption(PG_FUNCTION_ARGS)
   char seqscan_flags;
 
   {
-    const char *option = GetConfigOption("ludia.max_n_sort_result");
+    const char *option = getludiaoption("ludia.max_n_sort_result");
     if (option) {
       max_n_sort_result = atoi(option);
     } else {
@@ -524,7 +528,7 @@ pgs2getoption(PG_FUNCTION_ARGS)
     }
   }
   {
-    const char *option = GetConfigOption("ludia.enable_seqscan");
+    const char *option = getludiaoption("ludia.enable_seqscan");
     if (option) {
       strncpy(enable_seqscan, option, 16);
     } else {
@@ -532,7 +536,7 @@ pgs2getoption(PG_FUNCTION_ARGS)
     }
   }
   {
-    const char *option = GetConfigOption("ludia.seqscan_flags");
+    const char *option = getludiaoption("ludia.seqscan_flags");
     if (option) {
       seqscan_flags = atoi(option);
     } else {
@@ -540,7 +544,7 @@ pgs2getoption(PG_FUNCTION_ARGS)
     }
   }
   {
-    const char *option = GetConfigOption("ludia.sen_index_flags");
+    const char *option = getludiaoption("ludia.sen_index_flags");
     if (option) {
       sen_index_flags = atoi(option);
     } else {
@@ -548,7 +552,7 @@ pgs2getoption(PG_FUNCTION_ARGS)
     }
   }
   {
-    const char *option = GetConfigOption("ludia.max_n_index_cache");
+    const char *option = getludiaoption("ludia.max_n_index_cache");
     if (option) {
       max_n_index_cache = atoi(option);
     } else {
@@ -556,7 +560,7 @@ pgs2getoption(PG_FUNCTION_ARGS)
     }
   }
   {
-    const char *option = GetConfigOption("ludia.initial_n_segments");
+    const char *option = getludiaoption("ludia.initial_n_segments");
     if (option) {
       initial_n_segments = atoi(option);
     } else {
